@@ -12,18 +12,20 @@ using Suppressor
     using RCall
 end
 
+include("./display/basic.jl")
+include("./display/Rjulia.jl")
+include("./display/IRjulia.jl")
+include("./display/RmdJulia.jl")
+include("./display/plotsViewer.jl")
+include("REPLhook.jl")
+include("incomplete_console.jl")
+include("convert.jl")
+include("JuliaObject.jl")
+
 function transfer_list(x)
     rcopy(RObject(Ptr{RCall.VecSxp}(x)))
 end
 
-function transfer_string(x)
-    rcopy(RObject(Ptr{RCall.StrSxp}(x)))
-end
-
-function transfer_logical(x)
-    rcopy(RObject(Ptr{RCall.LglSxp}(x)))
-end
-
 function error_msg(e)
     m = IOBuffer()
     showerror(m, e)
@@ -49,15 +51,30 @@ function Rerror(fname, e, bt)
     rcall(:simpleError, s)
 end
 
-function docall(name, x, need_return1)
-    fname = transfer_string(name);
-    need_return = transfer_logical(need_return1);
+function docall(call1)
+    call = transfer_list(call1)
+    fname = call[:fname];
+    named_args = call[:named_args]
+    unamed_args = call[:unamed_args]
+    need_return = call[:need_return];
+    show_value = call[:show_value];
     try
-        f = eval(Main, parse(fname));
-        xx = transfer_list(x);
-        r = f(xx...);
-        if need_return
+        if endswith(fname, ".")
+            fname = chop(fname);
+            f = eval(Main, parse(fname));
+            r = f.(unamed_args...; named_args...);
+        else
+            f = eval(Main, parse(fname));
+            r = f(unamed_args...; named_args...);
+        end
+        if show_value && r != nothing
+            display(r)
+        end
+        proceed(basic_display_manager)
+        if need_return == "R"
             RObject(r).p;
+        elseif need_return == "Julia"
+            RObject(JuliaObject(r)).p
         else
             RObject(nothing).p;
         end;
@@ -82,4 +99,12 @@ function help(fname)
     string(eval_string(join(["@doc " fname])))
 end
 
+function assign(name, x)
+    eval(Main, Expr(:(=), Symbol(name), x))
+end
+
+function str_typeof(x)
+    string(typeof(x))
+end
+
 end
